From 88eaa77f833a90e024bbe99955e4bd7881ba3e44 Mon Sep 17 00:00:00 2001
From: olivierdalang <olivier.dalang@gmail.com>
Date: Mon, 11 Feb 2013 02:48:46 +0100
Subject: [PATCH] Declare properties of QgsCollapsibleGroupBox so they can be
 set through QtDesigner Update all UI files to add
 properties of QgsCollapsibleGroupBox

---
 python/gui/qgscollapsiblegroupbox.sip             | 11 +++++++++
 python/plugins/GdalTools/tools/widgetDEM.ui       |  2 +-
 python/plugins/GdalTools/tools/widgetTranslate.ui |  2 +-
 src/gui/qgscollapsiblegroupbox.h                  |  7 +++++-
 src/ui/qgscomposeritemwidgetbase.ui               |  4 +--
 src/ui/qgslabelingguibase.ui                      | 30 +++++++++++------------
 src/ui/qgsoptionsbase.ui                          |  4 +--
 src/ui/qgsprojectpropertiesbase.ui                | 10 ++++----
 src/ui/qgsrasterlayerpropertiesbase.ui            |  2 +-
 src/ui/qgsrasterlayersaveasdialogbase.ui          | 12 ++++-----
 10 files changed, 50 insertions(+), 34 deletions(-)

diff --git a/python/gui/qgscollapsiblegroupbox.sip b/python/gui/qgscollapsiblegroupbox.sip
index 93b909d..1313529 100644
--- a/python/gui/qgscollapsiblegroupbox.sip
+++ b/python/gui/qgscollapsiblegroupbox.sip
@@ -1,3 +1,14 @@
+
+/**
+ * \class QgsCollapsibleGroupBox
+ * \brief A groupbox that collapses/expands when toggled.
+ *
+ * By default, it auto-saves its collapsed state to the global settings based on the widget and it's parent names.
+ *
+ * @note To add Collapsible properties in promoted QtDesigner widgets, you can add the following "Dynamic properties" by clicking on the green + in the propreties palette :
+ * bool collapsed, bool saveCollapsedState, bool saveCheckedState
+ */
+
 class QgsCollapsibleGroupBox : QGroupBox
 {
 %TypeHeaderCode
diff --git a/python/plugins/GdalTools/tools/widgetDEM.ui b/python/plugins/GdalTools/tools/widgetDEM.ui
index d0fe438..9483887 100644
--- a/python/plugins/GdalTools/tools/widgetDEM.ui
+++ b/python/plugins/GdalTools/tools/widgetDEM.ui
@@ -410,7 +410,7 @@
     </widget>
    </item>
    <item>
-    <widget class="QgsCollapsibleGroupBox" name="creationOptionsGroupBox">
+    <widget class="QgsCollapsibleGroupBox" name="creationOptionsGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
      <property name="enabled">
       <bool>true</bool>
      </property>
diff --git a/python/plugins/GdalTools/tools/widgetTranslate.ui b/python/plugins/GdalTools/tools/widgetTranslate.ui
index 47d4077..3b3d5dc 100644
--- a/python/plugins/GdalTools/tools/widgetTranslate.ui
+++ b/python/plugins/GdalTools/tools/widgetTranslate.ui
@@ -250,7 +250,7 @@ The 'gray' value (from GDAL 1.7.0) enables to expand a dataset with a color tabl
     </layout>
    </item>
    <item>
-    <widget class="QgsCollapsibleGroupBox" name="creationOptionsGroupBox">
+    <widget class="QgsCollapsibleGroupBox" name="creationOptionsGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
      <property name="title">
       <string>&amp;Creation Options</string>
      </property>
diff --git a/src/gui/qgscollapsiblegroupbox.h b/src/gui/qgscollapsiblegroupbox.h
index 0977ad3..bb068d9 100644
--- a/src/gui/qgscollapsiblegroupbox.h
+++ b/src/gui/qgscollapsiblegroupbox.h
@@ -22,7 +22,9 @@
 
 /** \ingroup gui
  * A groupbox that collapses/expands when toggled.
- * @note Collapsible function not shown in promoted QtDesigner widgets.
+ * By default, it auto-saves its collapsed state to the global settings based on the widget and it's parent names.
+ * @note To add Collapsible properties in promoted QtDesigner widgets, you can add the following "Dynamic properties" by clicking on the green + in the propreties palette :
+ * bool collapsed, bool saveCollapsedState, bool saveCheckedState
  */
 
 #include <QGroupBox>
@@ -36,6 +38,9 @@ class GUI_EXPORT QgsCollapsibleGroupBox : public QGroupBox
 {
     Q_OBJECT
 
+    Q_PROPERTY(bool collapsed READ isCollapsed WRITE setCollapsed USER true)
+    Q_PROPERTY(bool saveCollapsedState READ saveCollapsedState WRITE setSaveCollapsedState USER true)
+    Q_PROPERTY(bool saveCheckedState READ saveCheckedState WRITE setSaveCheckedState USER true)
   public:
     QgsCollapsibleGroupBox( QWidget *parent = 0, QSettings* settings = 0 );
     QgsCollapsibleGroupBox( const QString &title, QWidget *parent = 0, QSettings* settings = 0 );
diff --git a/src/ui/qgscomposeritemwidgetbase.ui b/src/ui/qgscomposeritemwidgetbase.ui
index 720bba5..5f418ea 100644
--- a/src/ui/qgscomposeritemwidgetbase.ui
+++ b/src/ui/qgscomposeritemwidgetbase.ui
@@ -25,7 +25,7 @@
     </widget>
    </item>
    <item row="1" column="0" colspan="2">
-    <widget class="QgsCollapsibleGroupBox" name="mFrameGroupBox">
+    <widget class="QgsCollapsibleGroupBox" name="mFrameGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
      <property name="title">
       <string>Show frame</string>
      </property>
@@ -60,7 +60,7 @@
     </widget>
    </item>
    <item row="2" column="0" colspan="2">
-    <widget class="QgsCollapsibleGroupBox" name="mBackgroundGroupBox">
+    <widget class="QgsCollapsibleGroupBox" name="mBackgroundGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
      <property name="title">
       <string>Show background</string>
      </property>
diff --git a/src/ui/qgslabelingguibase.ui b/src/ui/qgslabelingguibase.ui
index 82d7461..92c9226 100644
--- a/src/ui/qgslabelingguibase.ui
+++ b/src/ui/qgslabelingguibase.ui
@@ -169,7 +169,7 @@
          <property name="childrenCollapsible">
           <bool>false</bool>
          </property>
-         <widget class="QgsCollapsibleGroupBox" name="groupBox_mPreview">
+         <widget class="QgsCollapsibleGroupBox" name="groupBox_mPreview"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
           <property name="sizePolicy">
            <sizepolicy hsizetype="Preferred" vsizetype="MinimumExpanding">
             <horstretch>0</horstretch>
@@ -462,7 +462,7 @@
              <number>20</number>
             </property>
             <item row="9" column="0">
-             <widget class="QgsCollapsibleGroupBox" name="chkFormattedNumbers">
+             <widget class="QgsCollapsibleGroupBox" name="chkFormattedNumbers"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
               <property name="sizePolicy">
                <sizepolicy hsizetype="Preferred" vsizetype="Maximum">
                 <horstretch>0</horstretch>
@@ -529,7 +529,7 @@
              </widget>
             </item>
             <item row="7" column="0">
-             <widget class="QgsCollapsibleGroupBox" name="mFontMultiLineGroupBox">
+             <widget class="QgsCollapsibleGroupBox" name="mFontMultiLineGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
               <property name="minimumSize">
                <size>
                 <width>0</width>
@@ -677,7 +677,7 @@
              </widget>
             </item>
             <item row="2" column="0">
-             <widget class="QgsCollapsibleGroupBox" name="mFontStyleGroupBox">
+             <widget class="QgsCollapsibleGroupBox" name="mFontStyleGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
               <property name="sizePolicy">
                <sizepolicy hsizetype="Preferred" vsizetype="Maximum">
                 <horstretch>0</horstretch>
@@ -1161,7 +1161,7 @@
              </widget>
             </item>
             <item row="4" column="0">
-             <widget class="QgsCollapsibleGroupBox" name="chkBuffer">
+             <widget class="QgsCollapsibleGroupBox" name="chkBuffer"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
               <property name="sizePolicy">
                <sizepolicy hsizetype="Preferred" vsizetype="Maximum">
                 <horstretch>0</horstretch>
@@ -1412,7 +1412,7 @@
              </spacer>
             </item>
             <item row="6" column="0">
-             <widget class="QgsCollapsibleGroupBox" name="mFontLimitPixelGroupBox">
+             <widget class="QgsCollapsibleGroupBox" name="mFontLimitPixelGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
               <property name="title">
                <string>Pixel size-based visibility</string>
               </property>
@@ -1550,7 +1550,7 @@
              </widget>
             </item>
             <item row="5" column="0">
-             <widget class="QgsCollapsibleGroupBox" name="chkScaleBasedVisibility">
+             <widget class="QgsCollapsibleGroupBox" name="chkScaleBasedVisibility"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
               <property name="sizePolicy">
                <sizepolicy hsizetype="Preferred" vsizetype="Maximum">
                 <horstretch>0</horstretch>
@@ -1691,7 +1691,7 @@
              </widget>
             </item>
             <item row="8" column="0">
-             <widget class="QgsCollapsibleGroupBox" name="mDirectSymbGroupBox">
+             <widget class="QgsCollapsibleGroupBox" name="mDirectSymbGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
               <property name="title">
                <string>Line direction symbols</string>
               </property>
@@ -1929,7 +1929,7 @@
             <number>6</number>
            </property>
            <item row="1" column="0">
-            <widget class="QgsCollapsibleGroupBox" name="mPriorityGroupBox">
+            <widget class="QgsCollapsibleGroupBox" name="mPriorityGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
              <property name="maximumSize">
               <size>
                <width>16777215</width>
@@ -1977,7 +1977,7 @@
             </widget>
            </item>
            <item row="0" column="0">
-            <widget class="QgsCollapsibleGroupBox" name="mPlacementGroupBox">
+            <widget class="QgsCollapsibleGroupBox" name="mPlacementGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
              <property name="sizePolicy">
               <sizepolicy hsizetype="Preferred" vsizetype="Maximum">
                <horstretch>0</horstretch>
@@ -2731,7 +2731,7 @@
             </spacer>
            </item>
            <item row="2" column="0">
-            <widget class="QgsCollapsibleGroupBox" name="mOptionsGroupBox">
+            <widget class="QgsCollapsibleGroupBox" name="mOptionsGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
              <property name="maximumSize">
               <size>
                <width>16777215</width>
@@ -3003,7 +3003,7 @@
             <number>6</number>
            </property>
            <item row="3" column="0">
-            <widget class="QgsCollapsibleGroupBox" name="mBufferAttributesPropertiesGroupBox">
+            <widget class="QgsCollapsibleGroupBox" name="mBufferAttributesPropertiesGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
              <property name="title">
               <string>Buffer properties</string>
              </property>
@@ -3049,7 +3049,7 @@
             </widget>
            </item>
            <item row="4" column="0">
-            <widget class="QgsCollapsibleGroupBox" name="mPositionAttributeGroupBox">
+            <widget class="QgsCollapsibleGroupBox" name="mPositionAttributeGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
              <property name="title">
               <string>Position</string>
              </property>
@@ -3147,7 +3147,7 @@
             </spacer>
            </item>
            <item row="1" column="0">
-            <widget class="QgsCollapsibleGroupBox" name="mDisplayAttributesPropertiesGroupBox">
+            <widget class="QgsCollapsibleGroupBox" name="mDisplayAttributesPropertiesGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
              <property name="title">
               <string>Display properties</string>
              </property>
@@ -3211,7 +3211,7 @@
             </widget>
            </item>
            <item row="2" column="0">
-            <widget class="QgsCollapsibleGroupBox" name="mFontAttributePropertiesGroupBox">
+            <widget class="QgsCollapsibleGroupBox" name="mFontAttributePropertiesGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
              <property name="sizePolicy">
               <sizepolicy hsizetype="Expanding" vsizetype="Preferred">
                <horstretch>0</horstretch>
diff --git a/src/ui/qgsoptionsbase.ui b/src/ui/qgsoptionsbase.ui
index cfa101c..9fa68fb 100644
--- a/src/ui/qgsoptionsbase.ui
+++ b/src/ui/qgsoptionsbase.ui
@@ -997,7 +997,7 @@
                    </widget>
                   </item>
                   <item row="2" column="0" colspan="4">
-                   <widget class="QgsCollapsibleGroupBox" name="mCurrentVariablesGrpBx">
+                   <widget class="QgsCollapsibleGroupBox" name="mCurrentVariablesGrpBx"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
                     <property name="minimumSize">
                      <size>
                       <width>0</width>
@@ -3790,7 +3790,7 @@
                 </widget>
                </item>
                <item>
-                <widget class="QgsCollapsibleGroupBox" name="grpProxy">
+                <widget class="QgsCollapsibleGroupBox" name="grpProxy"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
                  <property name="title">
                   <string>Use proxy for web access</string>
                  </property>
diff --git a/src/ui/qgsprojectpropertiesbase.ui b/src/ui/qgsprojectpropertiesbase.ui
index f963ddc..d7b385f 100644
--- a/src/ui/qgsprojectpropertiesbase.ui
+++ b/src/ui/qgsprojectpropertiesbase.ui
@@ -843,7 +843,7 @@
           </property>
           <layout class="QGridLayout" name="gridLayout_15">
            <item row="0" column="0">
-            <widget class="QgsCollapsibleGroupBox" name="grpOWSServiceCapabilities">
+            <widget class="QgsCollapsibleGroupBox" name="grpOWSServiceCapabilities"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
              <property name="title">
               <string>Service Capabilitities</string>
              </property>
@@ -979,7 +979,7 @@
              </property>
              <layout class="QGridLayout" name="gridLayout_14">
               <item row="0" column="0">
-               <widget class="QgsCollapsibleGroupBox" name="grpWMSExt">
+               <widget class="QgsCollapsibleGroupBox" name="grpWMSExt"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
                 <property name="title">
                  <string>Advertised Extent</string>
                 </property>
@@ -1082,7 +1082,7 @@
                </widget>
               </item>
               <item row="0" column="1" colspan="2">
-               <widget class="QgsCollapsibleGroupBox" name="grpWMSList">
+               <widget class="QgsCollapsibleGroupBox" name="grpWMSList"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
                 <property name="title">
                  <string>Coordinate Systems Restrictions</string>
                 </property>
@@ -1121,7 +1121,7 @@
                </widget>
               </item>
               <item row="1" column="0">
-               <widget class="QgsCollapsibleGroupBox" name="mWMSComposerGroupBox">
+               <widget class="QgsCollapsibleGroupBox" name="mWMSComposerGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
                 <property name="title">
                  <string>Exclude composers</string>
                 </property>
@@ -1174,7 +1174,7 @@
                </widget>
               </item>
               <item row="1" column="2">
-               <widget class="QgsCollapsibleGroupBox" name="mLayerRestrictionsGroupBox">
+               <widget class="QgsCollapsibleGroupBox" name="mLayerRestrictionsGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
                 <property name="title">
                  <string>Exclude layers</string>
                 </property>
diff --git a/src/ui/qgsrasterlayerpropertiesbase.ui b/src/ui/qgsrasterlayerpropertiesbase.ui
index 990e8db..9cb1e52 100644
--- a/src/ui/qgsrasterlayerpropertiesbase.ui
+++ b/src/ui/qgsrasterlayerpropertiesbase.ui
@@ -158,7 +158,7 @@
         </widget>
        </item>
        <item>
-        <widget class="QgsCollapsibleGroupBox" name="mResamplingGroupBox">
+        <widget class="QgsCollapsibleGroupBox" name="mResamplingGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
          <property name="title">
           <string>Resampling</string>
          </property>
diff --git a/src/ui/qgsrasterlayersaveasdialogbase.ui b/src/ui/qgsrasterlayersaveasdialogbase.ui
index cc5b759..ba30377 100644
--- a/src/ui/qgsrasterlayersaveasdialogbase.ui
+++ b/src/ui/qgsrasterlayersaveasdialogbase.ui
@@ -222,7 +222,7 @@ datasets with maximum width and height specified below.</string>
         <number>0</number>
        </property>
        <item>
-        <widget class="QgsCollapsibleGroupBox" name="mExtentGroupBox">
+        <widget class="QgsCollapsibleGroupBox" name="mExtentGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
          <property name="sizePolicy">
           <sizepolicy hsizetype="Preferred" vsizetype="Preferred">
            <horstretch>0</horstretch>
@@ -380,7 +380,7 @@ datasets with maximum width and height specified below.</string>
         </widget>
        </item>
        <item>
-        <widget class="QgsCollapsibleGroupBox" name="mResolutionGroupBox">
+        <widget class="QgsCollapsibleGroupBox" name="mResolutionGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
          <property name="sizePolicy">
           <sizepolicy hsizetype="Preferred" vsizetype="Preferred">
            <horstretch>0</horstretch>
@@ -465,7 +465,7 @@ datasets with maximum width and height specified below.</string>
         </widget>
        </item>
        <item>
-        <widget class="QgsCollapsibleGroupBox" name="mTilesGroupBox">
+        <widget class="QgsCollapsibleGroupBox" name="mTilesGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
          <property name="sizePolicy">
           <sizepolicy hsizetype="Preferred" vsizetype="Preferred">
            <horstretch>0</horstretch>
@@ -520,7 +520,7 @@ datasets with maximum width and height specified below.</string>
         </widget>
        </item>
        <item>
-        <widget class="QgsCollapsibleGroupBox" name="mCreateOptionsGroupBox">
+        <widget class="QgsCollapsibleGroupBox" name="mCreateOptionsGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
          <property name="sizePolicy">
           <sizepolicy hsizetype="Preferred" vsizetype="Preferred">
            <horstretch>0</horstretch>
@@ -544,7 +544,7 @@ datasets with maximum width and height specified below.</string>
         </widget>
        </item>
        <item>
-        <widget class="QgsCollapsibleGroupBox" name="mPyramidsGroupBox">
+        <widget class="QgsCollapsibleGroupBox" name="mPyramidsGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
          <property name="sizePolicy">
           <sizepolicy hsizetype="Preferred" vsizetype="Preferred">
            <horstretch>0</horstretch>
@@ -628,7 +628,7 @@ datasets with maximum width and height specified below.</string>
         </widget>
        </item>
        <item>
-        <widget class="QgsCollapsibleGroupBox" name="mNoDataGroupBox">
+        <widget class="QgsCollapsibleGroupBox" name="mNoDataGroupBox"><property name="collapsed" stdset="0"><bool>false</bool></property><property name="saveCheckedState" stdset="0"><bool>false</bool></property><property name="saveCollapsedState" stdset="0"><bool>true</bool></property>
          <property name="sizePolicy">
           <sizepolicy hsizetype="Preferred" vsizetype="Preferred">
            <horstretch>0</horstretch>
-- 
1.7.11.msysgit.0

